==> jc-1.4.0.tar.gz: java/awt/font/TextLayout__24CaretPolicy.c <==
// public class java.awt.font.TextLayout$CaretPolicy

// class file dependencies
// @dep_class d8e9bf3b8c0476f9 gnu_java_awt_peer_ClasspathTextLayoutPeer
// @dep_class cb469b6fcf30964f java_awt_font_TextHitInfo
// @dep_class 434c697ee872e9fb java_awt_font_TextLayout
// @dep_class d2158fad11ed751d java_awt_font_TextLayout__24CaretPolicy
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String

// header file dependencies
// @dep_header gnu_java_awt_peer_ClasspathTextLayoutPeer
// @dep_header java_awt_font_TextHitInfo
// @dep_header java_awt_font_TextLayout
// @dep_header java_awt_font_TextLayout__24CaretPolicy
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "gnu/java/awt/peer/ClasspathTextLayoutPeer.h"
#include "java/awt/font/TextHitInfo.h"
#include "java/awt/font/TextLayout.h"
#include "java/awt/font/TextLayout__24CaretPolicy.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_java_awt_font_TextLayout__24CaretPolicy$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_awt_font_TextLayout__24CaretPolicy$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_awt_font_TextLayout__24CaretPolicy$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_awt_font_TextLayout__24CaretPolicy$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_awt_font_TextLayout__24CaretPolicy$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_font_TextLayout__24CaretPolicy$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_font_TextLayout__24CaretPolicy$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_font_TextLayout__24CaretPolicy, _init$52f4ad9f2989aeee);

void
_jc_java_awt_font_TextLayout__24CaretPolicy$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_awt_font_TextLayout__24CaretPolicy$object *this)
{
	struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(67);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.awt.font.TextHitInfo getStrongCaret(java.awt.font.TextHitInfo, java.awt.font.TextHitInfo, java.awt.font.TextLayout)
//

static _jc_linenum _jc_java_awt_font_TextLayout__24CaretPolicy$linenum_table$getStrongCaret$f695232b1bb61e91[];

static const unsigned char _jc_java_awt_font_TextLayout__24CaretPolicy$param_ptypes$getStrongCaret$f695232b1bb61e91[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_awt_font_TextLayout__24CaretPolicy$param_types$getStrongCaret$f695232b1bb61e91[] = {
	&_jc_java_awt_font_TextHitInfo$type,
	&_jc_java_awt_font_TextHitInfo$type,
	&_jc_java_awt_font_TextLayout$type
};

_jc_method _jc_java_awt_font_TextLayout__24CaretPolicy$method_info$getStrongCaret$f695232b1bb61e91 = {
	.name=			"getStrongCaret",
	.signature=		"(Ljava/awt/font/TextHitInfo;Ljava/awt/font/TextHitInfo;Ljava/awt/font/TextLayout;)Ljava/awt/font/TextHitInfo;",
	.class=			&_jc_java_awt_font_TextLayout__24CaretPolicy$type,
	.param_types=		&_jc_java_awt_font_TextLayout__24CaretPolicy$param_types$getStrongCaret$f695232b1bb61e91,
	.return_type=		&_jc_java_awt_font_TextHitInfo$type,
	.param_ptypes=		&_jc_java_awt_font_TextLayout__24CaretPolicy$param_ptypes$getStrongCaret$f695232b1bb61e91,
	.signature_hash=	_JC_JLONG(0xf695232b1bb61e91),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_font_TextLayout__24CaretPolicy$method$getStrongCaret$f695232b1bb61e91,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtable, java_awt_font_TextLayout__24CaretPolicy.getStrongCaret$f695232b1bb61e91) / sizeof(void *),
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_font_TextLayout__24CaretPolicy$linenum_table$getStrongCaret$f695232b1bb61e91
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_font_TextLayout__24CaretPolicy, getStrongCaret$f695232b1bb61e91);

_jc_java_awt_font_TextHitInfo$object *
_jc_java_awt_font_TextLayout__24CaretPolicy$method$getStrongCaret$f695232b1bb61e91(_jc_env *const env, _jc_java_awt_font_TextLayout__24CaretPolicy$object *this, _jc_java_awt_font_TextHitInfo$object *param0, _jc_java_awt_font_TextHitInfo$object *param1, _jc_java_awt_font_TextLayout$object *param2)
{
	struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *r0;
	struct _jc_java_awt_font_TextHitInfo$object *r1;
	struct _jc_java_awt_font_TextHitInfo$object *r2;
	struct _jc_java_awt_font_TextLayout$object *r3;
	struct _jc_object *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	r3 = param2;
	_JC_LINE_NUMBER(72);				// 0
	r4 = _JC_REF_FIELD(env, r3, java_awt_font_TextLayout, peer);
	r2 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0xa50943f17f1331be), _jc_object *, r1, r2);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_awt_font_TextLayout__24CaretPolicy$methods[] = {
	&_jc_java_awt_font_TextLayout__24CaretPolicy$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_awt_font_TextLayout__24CaretPolicy$method_info$getStrongCaret$f695232b1bb61e91
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_bucket_29[] = {
	&_jc_java_awt_font_TextLayout__24CaretPolicy$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[29]=	_jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_bucket_29,
	[113]=	_jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_awt_font_TextLayout__24CaretPolicy$class_depends[] = {
	{ "gnu/java/awt/peer/ClasspathTextLayoutPeer",	_JC_JLONG(0xd8e9bf3b8c0476f9) },
	{ "java/awt/font/TextHitInfo",	_JC_JLONG(0xcb469b6fcf30964f) },
	{ "java/awt/font/TextLayout",	_JC_JLONG(0x434c697ee872e9fb) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_awt_font_TextLayout__24CaretPolicy$vtype _jc_java_awt_font_TextLayout__24CaretPolicy$type = {
    .type= {
	.name=			"java/awt/font/TextLayout$CaretPolicy",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xd2158fad11ed751d),
		.source_file=		"TextLayout.java",
		.instance_size=		sizeof(_jc_java_awt_font_TextLayout__24CaretPolicy$refs) + sizeof(_jc_java_awt_font_TextLayout__24CaretPolicy$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_awt_font_TextLayout__24CaretPolicy$methods) / sizeof(*_jc_java_awt_font_TextLayout__24CaretPolicy$methods),
		.methods=		_jc_java_awt_font_TextLayout__24CaretPolicy$methods,
		.instanceof_hash_table=	_jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_table,
		.outer_class=		&_jc_java_awt_font_TextLayout$type,
		.num_class_depends=		sizeof(_jc_java_awt_font_TextLayout__24CaretPolicy$class_depends) / sizeof(*_jc_java_awt_font_TextLayout__24CaretPolicy$class_depends),
		.class_depends=		_jc_java_awt_font_TextLayout__24CaretPolicy$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_awt_font_TextLayout__24CaretPolicy= {
	    .getStrongCaret$f695232b1bb61e91=
		&_jc_java_awt_font_TextLayout__24CaretPolicy$method$getStrongCaret$f695232b1bb61e91,
	},
    }
};

==> jc-1.4.5.tar.gz: java/awt/font/TextLayout__24CaretPolicy.c <==
// public class java.awt.font.TextLayout$CaretPolicy

// class file dependencies
// @dep_class d8e9bf3b8c0476f9 gnu_java_awt_peer_ClasspathTextLayoutPeer
// @dep_class cb469b6fcf30964f java_awt_font_TextHitInfo
// @dep_class 434c697ee872e9fb java_awt_font_TextLayout
// @dep_class d2158fad11ed751d java_awt_font_TextLayout__24CaretPolicy
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String

// header file dependencies
// @dep_header gnu_java_awt_peer_ClasspathTextLayoutPeer
// @dep_header java_awt_font_TextHitInfo
// @dep_header java_awt_font_TextLayout
// @dep_header java_awt_font_TextLayout__24CaretPolicy
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "gnu/java/awt/peer/ClasspathTextLayoutPeer.h"
#include "java/awt/font/TextHitInfo.h"
#include "java/awt/font/TextLayout.h"
#include "java/awt/font/TextLayout__24CaretPolicy.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_java_awt_font_TextLayout__24CaretPolicy$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_awt_font_TextLayout__24CaretPolicy$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_awt_font_TextLayout__24CaretPolicy$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_awt_font_TextLayout__24CaretPolicy$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_awt_font_TextLayout__24CaretPolicy$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_font_TextLayout__24CaretPolicy$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_font_TextLayout__24CaretPolicy$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_font_TextLayout__24CaretPolicy, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_awt_font_TextLayout__24CaretPolicy$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_awt_font_TextLayout__24CaretPolicy$object *this)
{
	struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(67);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.awt.font.TextHitInfo getStrongCaret(java.awt.font.TextHitInfo, java.awt.font.TextHitInfo, java.awt.font.TextLayout)
//

static _jc_linenum _jc_java_awt_font_TextLayout__24CaretPolicy$linenum_table$getStrongCaret$f695232b1bb61e91[];

static const unsigned char _jc_java_awt_font_TextLayout__24CaretPolicy$param_ptypes$getStrongCaret$f695232b1bb61e91[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_awt_font_TextLayout__24CaretPolicy$param_types$getStrongCaret$f695232b1bb61e91[] = {
	&_jc_java_awt_font_TextHitInfo$type,
	&_jc_java_awt_font_TextHitInfo$type,
	&_jc_java_awt_font_TextLayout$type
};

_jc_method _jc_java_awt_font_TextLayout__24CaretPolicy$method_info$getStrongCaret$f695232b1bb61e91 = {
	.name=			"getStrongCaret",
	.signature=		"(Ljava/awt/font/TextHitInfo;Ljava/awt/font/TextHitInfo;Ljava/awt/font/TextLayout;)Ljava/awt/font/TextHitInfo;",
	.class=			&_jc_java_awt_font_TextLayout__24CaretPolicy$type,
	.param_types=		&_jc_java_awt_font_TextLayout__24CaretPolicy$param_types$getStrongCaret$f695232b1bb61e91,
	.return_type=		&_jc_java_awt_font_TextHitInfo$type,
	.param_ptypes=		&_jc_java_awt_font_TextLayout__24CaretPolicy$param_ptypes$getStrongCaret$f695232b1bb61e91,
	.signature_hash=	_JC_JLONG(0xf695232b1bb61e91),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_awt_font_TextLayout__24CaretPolicy$method$getStrongCaret$f695232b1bb61e91,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtable, java_awt_font_TextLayout__24CaretPolicy.getStrongCaret$f695232b1bb61e91) / sizeof(void *),
	.num_parameters=	3,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_awt_font_TextLayout__24CaretPolicy$linenum_table$getStrongCaret$f695232b1bb61e91
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_awt_font_TextLayout__24CaretPolicy, getStrongCaret$f695232b1bb61e91);

_jc_java_awt_font_TextHitInfo$object * _JC_JCNI_ATTR
_jc_java_awt_font_TextLayout__24CaretPolicy$method$getStrongCaret$f695232b1bb61e91(_jc_env *const env, _jc_java_awt_font_TextLayout__24CaretPolicy$object *this, _jc_java_awt_font_TextHitInfo$object *param0, _jc_java_awt_font_TextHitInfo$object *param1, _jc_java_awt_font_TextLayout$object *param2)
{
	struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *r0;
	struct _jc_java_awt_font_TextHitInfo$object *r1;
	struct _jc_java_awt_font_TextHitInfo$object *r2;
	struct _jc_java_awt_font_TextLayout$object *r3;
	struct _jc_object *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	r3 = param2;
	_JC_LINE_NUMBER(72);				// 0
	r4 = _JC_REF_FIELD(env, r3, java_awt_font_TextLayout, peer);
	r2 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0xa50943f17f1331be), _jc_object *, (_jc_env *, struct _jc_object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextHitInfo$object *), r1, r2);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_awt_font_TextLayout__24CaretPolicy$methods[] = {
	&_jc_java_awt_font_TextLayout__24CaretPolicy$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_awt_font_TextLayout__24CaretPolicy$method_info$getStrongCaret$f695232b1bb61e91
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_bucket_29[] = {
	&_jc_java_awt_font_TextLayout__24CaretPolicy$type,
	_JC_NULL
};
static _jc_type *const _jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[29]=	_jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_bucket_29,
	[101]=	_jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_awt_font_TextLayout__24CaretPolicy$class_depends[] = {
	{ "gnu/java/awt/peer/ClasspathTextLayoutPeer",	_JC_JLONG(0xd8e9bf3b8c0476f9) },
	{ "java/awt/font/TextHitInfo",	_JC_JLONG(0xcb469b6fcf30964f) },
	{ "java/awt/font/TextLayout",	_JC_JLONG(0x434c697ee872e9fb) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_awt_font_TextLayout__24CaretPolicy$vtype _jc_java_awt_font_TextLayout__24CaretPolicy$type = {
    .type= {
	.name=			"java/awt/font/TextLayout$CaretPolicy",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xd2158fad11ed751d),
		.source_file=		"TextLayout.java",
		.instance_size=		sizeof(_jc_java_awt_font_TextLayout__24CaretPolicy$refs) + sizeof(_jc_java_awt_font_TextLayout__24CaretPolicy$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_awt_font_TextLayout__24CaretPolicy$methods) / sizeof(*_jc_java_awt_font_TextLayout__24CaretPolicy$methods),
		.methods=		_jc_java_awt_font_TextLayout__24CaretPolicy$methods,
		.instanceof_hash_table=	_jc_java_awt_font_TextLayout__24CaretPolicy$instanceof_hash_table,
		.outer_class=		&_jc_java_awt_font_TextLayout$type,
		.num_class_depends=		sizeof(_jc_java_awt_font_TextLayout__24CaretPolicy$class_depends) / sizeof(*_jc_java_awt_font_TextLayout__24CaretPolicy$class_depends),
		.class_depends=		_jc_java_awt_font_TextLayout__24CaretPolicy$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_awt_font_TextLayout__24CaretPolicy= {
	    .getStrongCaret$f695232b1bb61e91=
		&_jc_java_awt_font_TextLayout__24CaretPolicy$method$getStrongCaret$f695232b1bb61e91,
	},
    }
};
